@@ -4,6 +4,12 @@ from ftw.pdfgenerator.utils import html2xmlentities
 from xml.dom import minidom
 
 
+LIST_NESTING_LIMIT = 4
+"""LaTeX allows a maximum list nesting of 4. Deeper nesting will be flattened
+to the nesting limit so that the produced LaTeX code is still valid.
+"""
+
+
 class ListConverter(subconverter.SubConverter):
     """
     The ListConverter converts <ul> and <ol> lists
@@ -17,6 +23,10 @@ class ListConverter(subconverter.SubConverter):
         'dl': 'description',
     }
 
+    def __init__(self, *args, **kwargs):
+        super(ListConverter, self).__init__(*args, **kwargs)
+        self.nesting_level = 0
+
     def __call__(self):
         html = self.get_html()
         # cleanup html with BeautifulSoup
@@ -31,20 +41,10 @@ class ListConverter(subconverter.SubConverter):
         latex = []
 
         for node in dom.getElementsByTagName('dummy')[0].childNodes:
-            if node.nodeType == 1 and \
+            if node.nodeType == minidom.Node.ELEMENT_NODE and \
                     node.tagName.lower() in self.listing_tag_mapping.keys():
 
-                if node.tagName.lower() in ('ol', 'ul'):
-                    nodes_latex = self._convert_listing_items(node)
-
-                else:
-                    nodes_latex = self._convert_description_items(node)
-
-                if nodes_latex:
-                    begin_env, end_env = self._create_environ(node)
-                    latex.append(begin_env)
-                    latex.append(nodes_latex)
-                    latex.append(end_env)
+                latex.extend(self.convert_listing_environment(node))
 
             else:
                 latex.append(self.converter.convert(node.toxml()))
@@ -52,16 +52,60 @@ class ListConverter(subconverter.SubConverter):
         latex.append('')
         self.replace_and_lock('\n'.join(latex))
 
+    def convert_listing_environment(self, node):
+        """Converts a <ul>, <ol> or <dl> node to latex.
+        """
+        has_items = self._listing_has_items(node)
+
+        if has_items and not self.nesting_level >= LIST_NESTING_LIMIT:
+            self.nesting_level += 1
+            return self._convert_reduced_listing_environment(node)
+            self.nesting_level -= 1
+
+        else:
+            return self._convert_reduced_listing_environment(
+                node, environment=False)
+
+    def _listing_has_items(self, node):
+        for elm in node.childNodes:
+            if elm.nodeType == minidom.Node.ELEMENT_NODE and \
+                    elm.tagName.lower() in ('li', 'dt', 'dd'):
+                return True
+        return False
+
+    def _convert_reduced_listing_environment(self, node, environment=True):
+        """Internal method should only be called
+        by ``convert_listing_environment``.
+        """
+        if node.tagName.lower() in ('ol', 'ul'):
+            nodes_latex = self._convert_listing_items(node)
+
+        else:
+            nodes_latex = self._convert_description_items(node)
+
+        if not nodes_latex:
+            return []
+
+        elif environment:
+            begin_env, end_env = self._create_environ(node)
+            return ['', begin_env, nodes_latex, end_env]
+
+        else:
+            return [nodes_latex]
+
     def _convert_listing_items(self, list_node):
+        """Converts <li> nodes to LaTeX.
+        """
         latex = []
         for elm in list_node.childNodes:
-            if elm.nodeType == 1 and elm.tagName.lower() == 'li':
+            if elm.nodeType == minidom.Node.ELEMENT_NODE and \
+                    elm.tagName.lower() == 'li':
                 latex.append(r'\item %s' % (
                         self._get_node_content(elm).strip()))
 
-            elif elm.nodeType == 1 and \
+            elif elm.nodeType == minidom.Node.ELEMENT_NODE and \
                     elm.tagName.lower() in self.listing_tag_mapping.keys():
-                latex.append(self._convert_listing_items(elm))
+                latex.extend(self.convert_listing_environment(elm))
 
             else:
                 content_latex = self._get_node_content(elm)
@@ -71,23 +115,27 @@ class ListConverter(subconverter.SubConverter):
         return '\n'.join(latex)
 
     def _convert_description_items(self, list_node):
+        """Converts <dt> / <dd> nodes to LaTeX.
+        """
         latex = []
 
         dt_node = None
         for elm in list_node.childNodes:
-            if elm.nodeType == 1 and elm.tagName.lower() == 'dt':
+            if elm.nodeType == minidom.Node.ELEMENT_NODE and \
+                    elm.tagName.lower() == 'dt':
                 dt_node = elm
 
-            elif elm.nodeType == 1 and elm.tagName.lower() == 'dd' and \
+            elif elm.nodeType == minidom.Node.ELEMENT_NODE and \
+                    elm.tagName.lower() == 'dd' and \
                     dt_node is not None:
                 latex.append(r'\item[%s] %s' % (
                         self._get_node_content(dt_node).strip(),
                         self._get_node_content(elm).strip()))
                 dt_node = None
 
-            elif elm.nodeType == 1 and \
+            elif elm.nodeType == minidom.Node.ELEMENT_NODE and \
                     elm.tagName.lower() in self.listing_tag_mapping.keys():
-                latex.append(self._convert_description_items(elm))
+                latex.extend(self.convert_listing_environment(elm))
 
             else:
                 content_latex = self._get_node_content(elm)
@@ -97,7 +145,9 @@ class ListConverter(subconverter.SubConverter):
         return '\n'.join(latex)
 
     def _get_node_content(self, elm):
-        if elm.nodeType == 3:  # text node
+        """Returns the LaTeX for the node `elm`.
+        """
+        if elm.nodeType == minidom.Node.TEXT_NODE:
             content_html = elm.toxml().strip()
 
         else:  # tag node
@@ -111,6 +161,8 @@ class ListConverter(subconverter.SubConverter):
             return self.converter.convert(content_html)
 
     def _create_environ(self, list_):
+        """Creates an environment for the node `list_`.
+        """
         name = list_.tagName.lower()
         env = self.listing_tag_mapping[name]
 
