@@ -550,6 +550,25 @@ class LatexCell(object):
 
             if self.get_align() in mapping.keys():
                 latex = mapping[self.get_align()] + latex
+
+        if 'grey' in self.get_css_classes():
+            self.converter.converter.layout.use_package('xcolor')
+            latex = r'\textcolor{gray}{%s}' % latex
+
+        if 'footnotesize' in self.get_css_classes():
+            latex = r'\footnotesize %s' % latex
+
+        if 'scriptsize' in self.get_css_classes():
+            latex = r'\scriptsize %s' % latex
+
+        if 'bold' in self.get_css_classes():
+            latex = r'\textbf{%s}' % latex
+
+        if 'indent2' in self.get_css_classes():
+            latex = r'\hangindent 0.2cm\hspace{0.2cm} %s' % latex
+        elif 'indent10' in self.get_css_classes():
+            latex = r'\hangindent 1cm\hspace{1cm} %s' % latex
+
         return latex
 
     def is_head_cell(self):
